@@ -1,7 +1,7 @@
 # !/usr/bin/env python3
 # encoding: utf-8
 from inspect import stack
-from typing import Awaitable
+from typing import List
 
 apis = {('获取用户ID', 'get_bot_id'): [False, '此API不需要请求权限'],
         ('获取用户信息', 'get_bot_info'): ['GET', '/users/@me'],
@@ -119,6 +119,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -139,9 +140,10 @@ class ReplyModel:
                 code: int
                 message: str
 
-            data: list[__guild]
-            trace_id: list[str]
-            result: list[bool]
+            data: List[__guild]
+            http_code: List[int]
+            trace_id: List[str]
+            result: List[bool]
 
         return GetBotGuilds
 
@@ -160,6 +162,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -179,7 +182,8 @@ class ReplyModel:
                 code: int
                 message: str
 
-            data: list[__channels]
+            data: List[__channels]
+            http_code: int
             trace_id: str
             result: bool
 
@@ -196,7 +200,7 @@ class ReplyModel:
         op_user_id: str or None
         sub_type: int
         private_type: int
-        private_user_ids: list
+        private_user_ids: List[str]
         speak_permission: int
         application_id: str
         permissions: str
@@ -208,6 +212,7 @@ class ReplyModel:
 
         class GetChannelsInfo:
             data: channels
+            http_code: int
             trace_id: str
             result: bool
 
@@ -218,6 +223,7 @@ class ReplyModel:
 
         class CreateChannels:
             data: channels
+            http_code: int
             trace_id: str
             result: bool
 
@@ -228,6 +234,7 @@ class ReplyModel:
 
         class PatchChannels:
             data: channels
+            http_code: int
             trace_id: str
             result: bool
 
@@ -238,6 +245,7 @@ class ReplyModel:
 
         class DeleteChannels:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -251,7 +259,7 @@ class ReplyModel:
             bot: bool
 
         nick: str
-        roles: list
+        roles: List[str]
         joined_at: str
         deaf: bool
         mute: bool
@@ -263,9 +271,10 @@ class ReplyModel:
         member = self._Member
 
         class GetGuildMembers:
-            data: list[member]
-            trace_id: list[str]
-            result: list[bool]
+            data: List[member]
+            http_code: List[int]
+            trace_id: List[str]
+            result: List[bool]
 
         return GetGuildMembers
 
@@ -274,6 +283,7 @@ class ReplyModel:
 
         class GetMemberInfo:
             data: member
+            http_code: int
             trace_id: str
             result: bool
 
@@ -284,6 +294,7 @@ class ReplyModel:
 
         class DeleteMember:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -303,11 +314,12 @@ class ReplyModel:
         class GetGuildRoles:
             class data:
                 guild_id: str
-                roles: list[role_]
+                roles: List[role_]
                 role_num_limit: str
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -323,6 +335,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -339,6 +352,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -349,6 +363,7 @@ class ReplyModel:
 
         class DeleteRole:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -360,6 +375,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -377,6 +393,7 @@ class ReplyModel:
 
         class GetChannelMemberPermission:
             data: permission
+            http_code: int
             trace_id: str
             result: bool
 
@@ -387,6 +404,7 @@ class ReplyModel:
 
         class PutChannelMRPermission:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -404,6 +422,7 @@ class ReplyModel:
 
         class GetChannelRolePermission:
             data: permission
+            http_code: int
             trace_id: str
             result: bool
 
@@ -429,7 +448,7 @@ class ReplyModel:
 
         class member:
             joined_at: str
-            roles: list[str]
+            roles: List[str]
 
         channel_id: str
         guild_id: str
@@ -447,6 +466,7 @@ class ReplyModel:
             class data:
                 message: message_
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -470,6 +490,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -480,6 +501,7 @@ class ReplyModel:
 
         class DeleteMsg:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -490,11 +512,12 @@ class ReplyModel:
             class data:
                 disable_create_dm: bool
                 disable_push_msg: bool
-                channel_ids: list[str]
+                channel_ids: List[str]
                 channel_push_max_num: int
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -509,6 +532,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -519,6 +543,7 @@ class ReplyModel:
 
         class MuteMember:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -527,10 +552,11 @@ class ReplyModel:
     def mute_members(self):
         class MuteMembers:
             class data:
-                user_ids: list[str]
+                user_ids: List[str]
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -547,10 +573,11 @@ class ReplyModel:
                 channel_id: str
                 message_id: str
                 announces_type: int
-                recommend_channels: list[RecommendChannels]
+                recommend_channels: List[RecommendChannels]
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -561,6 +588,7 @@ class ReplyModel:
 
         class DeleteAnnounce:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -571,10 +599,11 @@ class ReplyModel:
             class data:
                 guild_id: str
                 channel_id: str
-                message_ids: list[str]
+                message_ids: List[str]
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
@@ -585,6 +614,7 @@ class ReplyModel:
 
         class DeletePinMsg:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -615,6 +645,7 @@ class ReplyModel:
 
         class GetSchedules:
             data: [schedule]
+            http_code: int
             trace_id: str
             result: bool
 
@@ -625,6 +656,7 @@ class ReplyModel:
 
         class ScheduleInfo:
             data: schedule
+            http_code: int
             trace_id: str
             result: bool
 
@@ -635,6 +667,7 @@ class ReplyModel:
 
         class DeleteSchedule:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -645,6 +678,7 @@ class ReplyModel:
 
         class Reactions:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -659,9 +693,10 @@ class ReplyModel:
             message: str
 
         class GetReactionUsers:
-            data: list[Users]
-            trace_id: list[str]
-            result: list[bool]
+            data: List[Users]
+            http_code: List[int]
+            trace_id: List[str]
+            result: List[bool]
 
         return GetReactionUsers
 
@@ -670,6 +705,7 @@ class ReplyModel:
 
         class Audio:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -707,10 +743,10 @@ class ReplyModel:
 
                         type = int
 
-                    elems: list[__ForumsSubContent]
+                    elems: List[__ForumsSubContent]
                     props: object
 
-                paragraphs: list[__ForumsContent]
+                paragraphs: List[__ForumsContent]
 
             thread_id: str
             title: str
@@ -726,9 +762,10 @@ class ReplyModel:
         thread = self.__Threads
 
         class GetThreads:
-            data: list[thread]
-            trace_id: list[str]
-            result: list[bool]
+            data: List[thread]
+            http_code: List[int]
+            trace_id: List[str]
+            result: List[bool]
 
         return GetThreads
 
@@ -737,6 +774,7 @@ class ReplyModel:
 
         class GetThreadInfo:
             data: thread
+            http_code: int
             trace_id: str
             result: bool
 
@@ -750,6 +788,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
         return CreateThread
@@ -759,6 +798,7 @@ class ReplyModel:
 
         class DeleteThread:
             data: temp
+            http_code: int
             trace_id: str
             result: bool
 
@@ -778,6 +818,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
         return GetGuildPermissions
@@ -795,6 +836,7 @@ class ReplyModel:
                 code: int
                 message: str
 
+            http_code: int
             trace_id: str
             result: bool
 
