@@ -1,51 +1,191 @@
 from os import PathLike
 from os.path import exists
 from time import time
-from aiohttp import ClientSession, TCPConnector, FormData
+from asyncio import get_event_loop
+from aiohttp import ClientSession, TCPConnector, FormData, ClientTimeout, multipart, hdrs, payload
 from json import loads
 from json.decoder import JSONDecodeError
 from io import BufferedReader
-from typing import Optional, Union, BinaryIO
+from typing import Optional, Union, BinaryIO, List, Tuple
 from ._api_model import ReplyModel, api_converter, api_converter_re
-from .utils import objectize, convert_color, async_regular_temp, async_http_temp, async_empty_temp, sdk_error_temp
+from ._utils import objectize, async_regular_temp, async_http_temp, async_empty_temp, sdk_error_temp
+from .utils import convert_color
+
+try:
+    from importlib.metadata import version
+
+    aio_version = version('aiohttp')
+except (ImportError, ModuleNotFoundError):
+    from pkg_resources import get_distribution
+
+    aio_version = get_distribution('aiohttp').version
+
+version_checking = (3, 8, 1)
+for version_index in range(3):
+    try:
+        if int(aio_version[2 * version_index]) < version_checking[version_index]:
+            print(f'\033[1;33m[warning] 注意你的aiohttp版本为{aio_version}，SDK建议升级到3.8.1，避免出现无法预计的错误\033[0m')
+            break
+    except (ValueError, IndexError):
+        pass
+
 
 reply_model = ReplyModel()
 security_header = {'Content-Type': 'application/json', 'charset': 'UTF-8'}
+retry_err_code = (101, 11281, 11252, 11263, 11242, 11252, 306003, 306005, 306006, 501002, 501003, 501004, 501006,
+                  501007, 501011, 501012, 620007)
+
+
+class _FormData(FormData):
+    def _gen_form_data(self) -> multipart.MultipartWriter:
+        """Encode a list of fields using the multipart/form-data MIME format"""
+        if self._is_processed:
+            return self._writer
+        for dispparams, headers, value in self._fields:
+            try:
+                if hdrs.CONTENT_TYPE in headers:
+                    part = payload.get_payload(
+                        value,
+                        content_type=headers[hdrs.CONTENT_TYPE],
+                        headers=headers,
+                        encoding=self._charset,
+                    )
+                else:
+                    part = payload.get_payload(
+                        value, headers=headers, encoding=self._charset
+                    )
+            except Exception as exc:
+                print(value)
+                raise TypeError(
+                    "Can not serialize value type: %r\n "
+                    "headers: %r\n value: %r" % (type(value), headers, value)
+                ) from exc
+
+            if dispparams:
+                part.set_content_disposition(
+                    "form-data", quote_fields=self._quote_fields, **dispparams
+                )
+                assert part.headers is not None
+                part.headers.popall(hdrs.CONTENT_LENGTH, None)
+
+            self._writer.append_payload(part)
+
+        self._is_processed = True
+        return self._writer
 
 
 class _Session:
-    def __init__(self, loop, **kwargs):
-        self.kwargs = kwargs
-        self.__session: Optional[ClientSession] = None
+    def __init__(self, loop, is_retry, is_log_error, logger, **kwargs):
+        self._is_retry = is_retry
+        self._is_log_error = is_log_error
+        self._logger = logger
+        self._kwargs = kwargs
+        self._session: Optional[ClientSession] = None
+        self._timeout = ClientTimeout(total=20)
         loop.run_until_complete(self.check_session())
 
+    def __del__(self):
+        if self._session and not self._session.closed:
+            _loop = get_event_loop()
+            _loop.run_until_complete(self._session.close())
+
     async def check_session(self):
-        if not self.__session or self.__session.closed:
-            self.__session = ClientSession(**self.kwargs)
+        if not self._session or self._session.closed:
+            self._session = ClientSession(**self._kwargs)
 
-    async def get(self, url, **kwargs):
-        await self.check_session()
-        return await self.__session.get(url, **kwargs)
+    async def _warning(self, url, resp):
+        self._logger.warning(f'HTTP API(url:{url})调用错误[{resp.status}]，详情：{await resp.text()}，'
+                             f'trace_id：{resp.headers["X-Tps-Trace-Id"]}')
 
-    async def post(self, url, **kwargs):
+    async def get(self, url, retry=False, **kwargs):
         await self.check_session()
-        return await self.__session.post(url, **kwargs)
+        resp = await self._session.get(url, timeout=self._timeout, **kwargs)
+        if resp.ok:
+            return resp
+        if self._is_log_error and (not self._is_retry or retry):
+            await self._warning(url, resp)
+        if self._is_retry and not retry:
+            if resp.headers['content-type'] == 'application/json':
+                json_ = await resp.json()
+                if not isinstance(json_, dict) or json_.get('code', None) not in retry_err_code:
+                    if self._is_log_error:
+                        await self._warning(url, resp)
+                    return resp
+            return await self.get(url, True, **kwargs)
+        return resp
 
-    async def patch(self, url, **kwargs):
+    async def post(self, url, retry=False, **kwargs):
         await self.check_session()
-        return await self.__session.patch(url, **kwargs)
+        resp = await self._session.post(url, timeout=self._timeout, **kwargs)
+        if resp.ok:
+            return resp
+        if self._is_log_error and (not self._is_retry or retry):
+            await self._warning(url, resp)
+        if self._is_retry and not retry:
+            if resp.headers['content-type'] == 'application/json':
+                json_ = await resp.json()
+                if not isinstance(json_, dict) or json_.get('code', None) not in retry_err_code:
+                    if self._is_log_error:
+                        await self._warning(url, resp)
+                    return resp
+            return await self.post(url, True, **kwargs)
+        return resp
 
-    async def delete(self, url, **kwargs):
+    async def patch(self, url, retry=False, **kwargs):
         await self.check_session()
-        return await self.__session.delete(url, **kwargs)
+        resp = await self._session.patch(url, timeout=self._timeout, **kwargs)
+        if resp.ok:
+            return resp
+        if self._is_log_error and (not self._is_retry or retry):
+            await self._warning(url, resp)
+        if self._is_retry and not retry:
+            if resp.headers['content-type'] == 'application/json':
+                json_ = await resp.json()
+                if not isinstance(json_, dict) or json_.get('code', None) not in retry_err_code:
+                    if self._is_log_error:
+                        await self._warning(url, resp)
+                    return resp
+            return await self.patch(url, True, **kwargs)
+        return resp
 
-    async def put(self, url, **kwargs):
+    async def delete(self, url, retry=False, **kwargs):
         await self.check_session()
-        return await self.__session.put(url, **kwargs)
+        resp = await self._session.delete(url, timeout=self._timeout, **kwargs)
+        if resp.ok:
+            return resp
+        if self._is_log_error and (not self._is_retry or retry):
+            await self._warning(url, resp)
+        if self._is_retry and not retry:
+            if resp.headers['content-type'] == 'application/json':
+                json_ = await resp.json()
+                if not isinstance(json_, dict) or json_.get('code', None) not in retry_err_code:
+                    if self._is_log_error:
+                        await self._warning(url, resp)
+                    return resp
+            return await self.delete(url, True, **kwargs)
+        return resp
+
+    async def put(self, url, retry=False, **kwargs):
+        await self.check_session()
+        resp = await self._session.put(url, timeout=self._timeout, **kwargs)
+        if resp.ok:
+            return resp
+        if self._is_log_error and (not self._is_retry or retry):
+            await self._warning(url, resp)
+        if self._is_retry and not retry:
+            if resp.headers['content-type'] == 'application/json':
+                json_ = await resp.json()
+                if not isinstance(json_, dict) or json_.get('code', None) not in retry_err_code:
+                    if self._is_log_error:
+                        await self._warning(url, resp)
+                    return resp
+            return await self.put(url, True, **kwargs)
+        return resp
 
 
 class AsyncAPI:
-    def __init__(self, bot_url, bot_id, bot_secret, ssl, headers, logger, loop, check_warning, get_bot_id):
+    def __init__(self, bot_url, bot_id, bot_secret, ssl, headers, logger, loop, check_warning, get_bot_id, is_retry,
+                 is_log_error):
         self.bot_url = bot_url
         self.bot_id = bot_id
         self.bot_secret = bot_secret
@@ -53,8 +193,8 @@ class AsyncAPI:
         self.logger = logger
         self.loop = loop
         self.check_warning = check_warning
-        self.__client_conn = TCPConnector(limit=500, ssl=ssl)
-        self.__session = _Session(loop, headers=headers, connector=self.__client_conn)
+        self.__client_conn = TCPConnector(limit=500, ssl=ssl, force_close=True)
+        self.__session = _Session(loop, is_retry, is_log_error, logger, headers=headers, connector=self.__client_conn)
         self.__get_function = get_bot_id
         self.security_code = ''
         self.code_expire = 0
@@ -64,7 +204,7 @@ class AsyncAPI:
             self.logger.error('无法调用内容安全检测接口（备注：没有填入机器人密钥）')
             return None
         return_ = await self.__session.get(f'https://api.q.qq.com/api/getToken?grant_type=client_credential&'
-                                      f'appid={self.bot_id}&secret={self.bot_secret}')
+                                           f'appid={self.bot_id}&secret={self.bot_secret}')
         code = await return_.json()
         try:
             self.security_code = code['access_token']
@@ -83,14 +223,16 @@ class AsyncAPI:
         """
         if not self.security_code or time() >= self.code_expire:
             await self.__security_check_code()
-        return_ = await self.__session.post(f'https://api.q.qq.com/api/json/security/MsgSecCheck?access_token='
-                                       f'{self.security_code}', json={'content': content})
+        return_ = await self.__session.post(
+            f'https://api.q.qq.com/api/json/security/MsgSecCheck?access_token={self.security_code}',
+            json={'content': content}, headers=security_header)
         check = await return_.json()
         self.logger.debug(check)
         if check['errCode'] in (-1800110107, -1800110108):
             await self.__security_check_code()
-            return_ = await self.__session.post(f'https://api.q.qq.com/api/json/security/MsgSecCheck?access_token='
-                                           f'{self.security_code}', json={'content': content})
+            return_ = await self.__session.post(
+                f'https://api.q.qq.com/api/json/security/MsgSecCheck?access_token={self.security_code}',
+                json={'content': content}, headers=security_header)
             check = await return_.json()
             self.logger.debug(check)
         if check['errCode'] == 0:
@@ -116,6 +258,7 @@ class AsyncAPI:
         :return: 返回的.data中为包含所有数据的一个list，列表每个项均为object数据
         """
         trace_ids = []
+        codes = []
         results = []
         data = []
         return_dict = None
@@ -128,6 +271,7 @@ class AsyncAPI:
                 else:
                     break
                 trace_ids.append(return_.headers['X-Tps-Trace-Id'])
+                codes.append(return_.status)
                 return_dict = await return_.json()
                 if isinstance(return_dict, dict) and 'code' in return_dict.keys():
                     results.append(False)
@@ -138,8 +282,8 @@ class AsyncAPI:
                     for items in return_dict:
                         data.append(items)
         except JSONDecodeError:
-            return objectize({'data': [], 'trace_id': trace_ids, 'result': False})
-        return objectize({'data': data, 'trace_id': trace_ids, 'result': results})
+            return objectize({'data': [], 'trace_id': trace_ids, 'http_code': codes, 'result': False})
+        return objectize({'data': data, 'trace_id': trace_ids, 'http_code': codes, 'result': results})
 
     async def get_guild_info(self, guild_id: str) -> reply_model.get_guild_info():
         """
@@ -172,7 +316,7 @@ class AsyncAPI:
         return await async_regular_temp(return_)
 
     async def create_channels(self, guild_id: str, name: str, type_: int, position: int, parent_id: str, sub_type: int,
-                              private_type: int, private_user_ids: list[str], speak_permission: int,
+                              private_type: int, private_user_ids: List[str], speak_permission: int,
                               application_id: Optional[str] = None) -> reply_model.create_channels():
         """
         用于在 guild_id 指定的频道下创建一个子频道，一般仅私域机器人可用
@@ -234,40 +378,38 @@ class AsyncAPI:
         :param guild_id: 频道id
         :return: 返回的.data中为包含所有数据的一个list，列表每个项均为object数据
         """
-        return_ = await self.__session.get(f'{self.bot_url}/guilds/{guild_id}/members?limit=400')
-        trace_ids = [return_.headers['X-Tps-Trace-Id']]
+        trace_ids = []
+        codes = []
         results = []
         data = []
+        return_dict = None
         try:
-            return_dict = await return_.json()
-            if isinstance(return_dict, dict) and 'code' in return_dict.keys():
-                results.append(False)
-                return objectize({'data': [return_dict], 'trace_id': trace_ids, 'result': results})
-            else:
-                results.append(True)
-                for items in return_dict:
-                    data.append(items)
             while True:
-                if len(return_dict) == 400:
+                if return_dict is None:
+                    return_ = await self.__session.get(f'{self.bot_url}/guilds/{guild_id}/members?limit=400')
+                elif not return_dict:
+                    break
+                else:
                     return_ = await self.__session.get(f'{self.bot_url}/guilds/{guild_id}/members?limit=400&after=' +
                                                        return_dict[-1]['user']['id'])
-                    trace_ids.append(return_.headers['X-Tps-Trace-Id'])
-                    return_dict = await return_.json()
-                    if isinstance(return_dict, dict) and 'code' in return_dict.keys():
-                        results.append(False)
-                    else:
-                        results.append(True)
-                        for items in return_dict:
-                            if items not in data:
-                                data.append(items)
-                else:
+                trace_ids.append(return_.headers['X-Tps-Trace-Id'])
+                codes.append(return_.status)
+                return_dict = await return_.json()
+                if isinstance(return_dict, dict) and 'code' in return_dict.keys():
+                    results.append(False)
+                    data.append(return_dict)
                     break
+                else:
+                    results.append(True)
+                    for items in return_dict:
+                        if items not in data:
+                            data.append(items)
         except JSONDecodeError:
-            return objectize({'data': [], 'trace_id': trace_ids, 'result': [False]})
+            return objectize({'data': [], 'trace_id': trace_ids, 'http_code': codes, 'result': [False]})
         if data:
-            return objectize({'data': data, 'trace_id': trace_ids, 'result': results})
+            return objectize({'data': data, 'trace_id': trace_ids, 'http_code': codes, 'result': results})
         else:
-            return objectize({'data': [], 'trace_id': trace_ids, 'result': [False]})
+            return objectize({'data': [], 'trace_id': trace_ids, 'http_code': codes, 'result': [False]})
 
     async def get_member_info(self, guild_id: str, user_id: str) -> reply_model.get_member_info():
         """
@@ -309,7 +451,7 @@ class AsyncAPI:
         return await async_regular_temp(return_)
 
     async def create_role(self, guild_id: str, name: Optional[str] = None, hoist: Optional[bool] = None,
-                          color: Optional[Union[str, tuple[int, int, int]]] = None) -> reply_model.create_role():
+                          color: Optional[Union[str, Tuple[int, int, int]]] = None) -> reply_model.create_role():
         """
         用于在 guild_id 指定的频道下创建一个身份组
 
@@ -335,7 +477,7 @@ class AsyncAPI:
         return await async_regular_temp(return_)
 
     async def patch_role(self, guild_id: str, role_id: str, name: Optional[str] = None, hoist: Optional[bool] = None,
-                         color: Optional[Union[str, tuple[int, int, int]]] = None) -> reply_model.patch_role():
+                         color: Optional[Union[str, Tuple[int, int, int]]] = None) -> reply_model.patch_role():
         """
         用于修改频道 guild_id 下 role_id 指定的身份组
 
@@ -441,7 +583,7 @@ class AsyncAPI:
             return sdk_error_temp('注意add或remove的值只能为为1、2、4或8的文本格式内容')
         json_ = {'add': add, 'remove': remove}
         return_ = await self.__session.put(f'{self.bot_url}/channels/{channel_id}/members/{user_id}/permissions',
-                                      json=json_)
+                                           json=json_)
         return await async_http_temp(return_, 204)
 
     async def get_channel_role_permission(self, channel_id: str, role_id: str) -> \
@@ -471,7 +613,7 @@ class AsyncAPI:
             return sdk_error_temp('注意add或remove的值只能为为1、2、4或8的文本格式内容')
         json_ = {'add': add, 'remove': remove}
         return_ = await self.__session.put(f'{self.bot_url}/channels/{channel_id}/roles/{role_id}/permissions',
-                                      json=json_)
+                                           json=json_)
         return await async_http_temp(return_, 204)
 
     async def get_message_info(self, channel_id: str, message_id: str) -> reply_model.get_message_info():
@@ -521,7 +663,7 @@ class AsyncAPI:
                 else:
                     return sdk_error_temp('目标图片路径不存在，无法发送')
             json_['file_image'] = file_image
-            data_ = FormData()
+            data_ = _FormData()
             for keys, values in json_.items():
                 if values is not None:
                     data_.add_field(keys, values)
@@ -530,7 +672,7 @@ class AsyncAPI:
             return_ = await self.__session.post(f'{self.bot_url}/channels/{channel_id}/messages', json=json_)
         return await async_regular_temp(return_)
 
-    async def send_embed(self, channel_id: str, title: Optional[str] = None, content: Optional[list[str]] = None,
+    async def send_embed(self, channel_id: str, title: Optional[str] = None, content: Optional[List[str]] = None,
                          image: Optional[str] = None, prompt: Optional[str] = None, message_id: Optional[str] = None,
                          event_id: Optional[str] = None) -> reply_model.send_msg():
         """
@@ -553,7 +695,7 @@ class AsyncAPI:
         return_ = await self.__session.post(f'{self.bot_url}/channels/{channel_id}/messages', json=json_)
         return await async_regular_temp(return_)
 
-    async def send_ark_23(self, channel_id: str, content: list[str], link: list[str], desc: Optional[str] = None,
+    async def send_ark_23(self, channel_id: str, content: List[str], link: List[str], desc: Optional[str] = None,
                           prompt: Optional[str] = None, message_id: Optional[str] = None,
                           event_id: Optional[str] = None) -> reply_model.send_msg():
         """
@@ -645,7 +787,7 @@ class AsyncAPI:
         """
         self.check_warning('撤回消息')
         return_ = await self.__session.delete(f'{self.bot_url}/channels/{channel_id}/messages/{message_id}'
-                                         f'?hidetip={str(hidetip).lower()}')
+                                              f'?hidetip={str(hidetip).lower()}')
         return await async_http_temp(return_, 200)
 
     async def get_guild_setting(self, guild_id: str) -> reply_model.get_guild_setting():
@@ -706,7 +848,7 @@ class AsyncAPI:
                 else:
                     return sdk_error_temp('目标图片路径不存在，无法发送')
             json_['file_image'] = file_image
-            data_ = FormData()
+            data_ = _FormData()
             for keys, values in json_.items():
                 if values is not None:
                     data_.add_field(keys, values)
@@ -726,7 +868,7 @@ class AsyncAPI:
         """
         self.check_warning('撤回私信消息')
         return_ = await self.__session.delete(f'{self.bot_url}/dms/{guild_id}/messages/{message_id}?'
-                                         f'hidetip={str(hidetip).lower()}')
+                                              f'hidetip={str(hidetip).lower()}')
         return await async_http_temp(return_, 200)
 
     async def mute_all_member(self, guild_id: str, mute_end_timestamp: Optional[str], mute_seconds: Optional[str]) -> \
@@ -756,10 +898,10 @@ class AsyncAPI:
         """
         json_ = {'mute_end_timestamp': mute_end_timestamp, 'mute_seconds': mute_seconds}
         return_ = await self.__session.patch(f'{self.bot_url}/guilds/{guild_id}/members/{user_id}/mute',
-                                        json=json_)
+                                             json=json_)
         return await async_http_temp(return_, 204)
 
-    async def mute_members(self, guild_id: str, user_id: list[str], mute_end_timestamp: Optional[str],
+    async def mute_members(self, guild_id: str, user_id: List[str], mute_end_timestamp: Optional[str],
                            mute_seconds: Optional[str]) -> reply_model.mute_members():
         """
         用于将频道的指定批量成员（非管理员）禁言
@@ -773,19 +915,20 @@ class AsyncAPI:
         json_ = {'mute_end_timestamp': mute_end_timestamp, 'mute_seconds': mute_seconds, 'user_ids': user_id}
         return_ = await self.__session.patch(f'{self.bot_url}/guilds/{guild_id}/mute', json=json_)
         trace_id = return_.headers['X-Tps-Trace-Id']
+        status_code = return_.status
         try:
             return_dict = await return_.json()
-            if return_.status == 200:
+            if status_code == 200:
                 result = False
             else:
                 result = True
-            return objectize({'data': return_dict, 'trace_id': trace_id, 'result': result})
+            return objectize({'data': return_dict, 'trace_id': trace_id, 'http_code': status_code, 'result': result})
         except JSONDecodeError:
-            return objectize({'data': None, 'trace_id': trace_id, 'result': False})
+            return objectize({'data': None, 'trace_id': trace_id, 'http_code': status_code, 'result': False})
 
     async def create_announce(self, guild_id, channel_id: Optional[str] = None, message_id: Optional[str] = None,
-                              announces_type: Optional[int] = None, recommend_channels_id: Optional[list[str]] = None,
-                              recommend_channels_introduce: Optional[list[str]] = None) -> \
+                              announces_type: Optional[int] = None, recommend_channels_id: Optional[List[str]] = None,
+                              recommend_channels_introduce: Optional[List[str]] = None) -> \
             reply_model.create_announce():
         """
         用于创建频道全局公告，公告类型分为 消息类型的频道公告 和 推荐子频道类型的频道公告
@@ -913,7 +1056,7 @@ class AsyncAPI:
                               "end_timestamp": end_timestamp, "jump_channel_id": jump_channel_id,
                               "remind_type": remind_type}}
         return_ = await self.__session.patch(f'{self.bot_url}/channels/{channel_id}/schedules/{schedule_id}',
-                                        json=json_)
+                                             json=json_)
         return await async_regular_temp(return_)
 
     async def delete_schedule(self, channel_id: str, schedule_id: str) -> reply_model.delete_schedule():
@@ -938,7 +1081,7 @@ class AsyncAPI:
         :return: 返回的.result显示是否成功
         """
         return_ = await self.__session.put(f'{self.bot_url}/channels/{channel_id}/messages/{message_id}/reactions/'
-                                      f'{type_}/{id_}')
+                                           f'{type_}/{id_}')
         return await async_http_temp(return_, 204)
 
     async def delete_reaction(self, channel_id: str, message_id: str, type_: str, id_: str) -> reply_model.reactions():
@@ -952,7 +1095,7 @@ class AsyncAPI:
         :return: 返回的.result显示是否成功
         """
         return_ = await self.__session.delete(f'{self.bot_url}/channels/{channel_id}/messages/{message_id}/reactions/'
-                                         f'{type_}/{id_}')
+                                              f'{type_}/{id_}')
         return await async_http_temp(return_, 204)
 
     async def get_reaction_users(self, channel_id: str, message_id: str, type_: str, id_: str) -> \
@@ -969,6 +1112,7 @@ class AsyncAPI:
         return_ = await self.__session.get(f'{self.bot_url}/channels/{channel_id}/messages/{message_id}/reactions/'
                                            f'{type_}/{id_}?cookie=&limit=50')
         trace_ids = [return_.headers['X-Tps-Trace-Id']]
+        codes = [return_.status]
         all_users = []
         try:
             return_dict = await return_.json()
@@ -985,6 +1129,7 @@ class AsyncAPI:
                     return_ = await self.__session.get(f'{self.bot_url}/channels/{channel_id}/messages/{message_id}/'
                                                        f'reactions/{type_}/{id_}?cookies={return_dict["cookie"]}')
                     trace_ids.append(return_.headers['X-Tps-Trace-Id'])
+                    codes.append(return_.status)
                     return_dict = await return_.json()
                     if isinstance(return_dict, dict) and 'code' in return_dict.keys():
                         results.append(False)
@@ -994,12 +1139,12 @@ class AsyncAPI:
                         results.append(True)
                         for items in return_dict['users']:
                             all_users.append(items)
-            return objectize({'data': all_users, 'trace_id': trace_ids, 'result': results})
+            return objectize({'data': all_users, 'trace_id': trace_ids, 'http_code': codes, 'result': results})
         except JSONDecodeError:
-            return objectize({'data': None, 'trace_id': trace_ids, 'result': [False]})
+            return objectize({'data': None, 'trace_id': trace_ids, 'http_code': codes, 'result': [False]})
 
     async def control_audio(self, channel_id: str, status: int, audio_url: Optional[str] = None,
-                      text: Optional[str] = None) -> reply_model.audio():
+                            text: Optional[str] = None) -> reply_model.audio():
         """
         用于控制子频道 channel_id 下的音频
 
@@ -1043,6 +1188,7 @@ class AsyncAPI:
         self.check_warning('获取帖子列表')
         return_ = await self.__session.get(f'{self.bot_url}/channels/{channel_id}/threads')
         trace_ids = [return_.headers['X-Tps-Trace-Id']]
+        codes = [return_.status]
         all_threads = []
         try:
             return_dict = await return_.json()
@@ -1060,6 +1206,7 @@ class AsyncAPI:
                         break
                     return_ = await self.__session.get(f'{self.bot_url}/channels/{channel_id}/threads')
                     trace_ids.append(return_.headers['X-Tps-Trace-Id'])
+                    codes.append(return_.status)
                     return_dict = await return_.json()
                     if isinstance(return_dict, dict) and 'code' in return_dict.keys():
                         results.append(False)
@@ -1071,9 +1218,9 @@ class AsyncAPI:
                             if 'thread_info' in items.keys() and 'content' in items['thread_info'].keys():
                                 items['thread_info']['content'] = loads(items['thread_info']['content'])
                             all_threads.append(items)
-            return objectize({'data': all_threads, 'trace_id': trace_ids, 'result': results})
+            return objectize({'data': all_threads, 'trace_id': trace_ids, 'http_code': codes, 'result': results})
         except JSONDecodeError:
-            return objectize({'data': None, 'trace_id': trace_ids, 'result': [False]})
+            return objectize({'data': None, 'trace_id': trace_ids, 'http_code': codes, 'result': [False]})
 
     async def get_thread_info(self, channel_id: str, thread_id: str) -> reply_model.get_thread_info():
         """
@@ -1133,9 +1280,9 @@ class AsyncAPI:
                 for i in range(len(return_dict['apis'])):
                     api = api_converter_re(return_dict['apis'][i]['method'], return_dict['apis'][i]['path'])
                     return_dict['apis'][i]['api'] = api
-            return objectize({'data': return_dict, 'trace_id': trace_id, 'result': result})
+            return objectize({'data': return_dict, 'trace_id': trace_id, 'http_code': return_.status, 'result': result})
         except JSONDecodeError:
-            return objectize({'data': None, 'trace_id': trace_id, 'result': False})
+            return objectize({'data': None, 'trace_id': trace_id, 'http_code': return_.status, 'result': False})
 
     async def create_permission_demand(self, guild_id: str, channel_id: str, api: str, desc: str or None) -> \
             reply_model.create_permission_demand():
@@ -1153,5 +1300,5 @@ class AsyncAPI:
             return sdk_error_temp('目标API不存在，请检查API名称是否正确')
         json_ = {"channel_id": channel_id, "api_identify": {"path": path, "method": method.upper()}, "desc": desc}
         return_ = await self.__session.post(f'{self.bot_url}/guilds/{guild_id}/api_permission/demand',
-                                       json=json_)
+                                            json=json_)
         return await async_empty_temp(return_)
