@@ -1,26 +1,24 @@
 # !/usr/bin/env python3
 # encoding: utf-8
-from os import getpid, system
+from os import getpid
 from asyncio import get_event_loop, sleep
 from time import sleep as t_sleep
 from ssl import SSLContext
 from requests import Session
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
-from threading import Thread
 from typing import Any, Callable, Union
 from .logger import Logger
 from .model import Model
 from ._api_model import ReplyModel
 from .qg_bot_ws import BotWs
-from .utils import objectize, exception_handler
+from ._utils import objectize, exception_handler
 from .api import API
 
-system("")
 reply_model = ReplyModel()
 retry = Retry(total=4, connect=3, backoff_factor=0.5)
 adapter = HTTPAdapter(max_retries=retry)
-version = '2.2.6'
+version = '2.3.1'
 pid = getpid()
 print(f'本次程序进程ID：{pid} | SDK版本：{version} | 即将开始运行机器人……')
 t_sleep(0.5)
@@ -29,8 +27,8 @@ t_sleep(0.5)
 class BOT:
 
     def __init__(self, bot_id: str, bot_token: str, bot_secret: str = None, is_private: bool = False,
-                 is_sandbox: bool = False, max_shard: int = 5, no_permission_warning: bool = True,
-                 is_async: bool = False):
+                 is_sandbox: bool = False, no_permission_warning: bool = True, is_async: bool = False,
+                 is_retry: bool = True, is_log_error: bool = True, shard_no: int = 0, total_shard: int = 1):
         """
         机器人主体，输入BotAppID和密钥，并绑定函数后即可快速使用
 
@@ -39,9 +37,12 @@ class BOT:
         :param bot_secret: 机器人平台后台机器人密钥项，如需要使用安全检测功能需填写此项
         :param is_private: 机器人是否为私域机器人，默认False
         :param is_sandbox: 是否开启沙箱环境，默认False
-        :param max_shard: 最大分片数，请根据配置自行判断，默认5
         :param no_permission_warning: 是否开启当机器人获取疑似权限不足的事件时的警告提示，默认开启
         :param is_async: 使用同步api还是异步api，默认False（使用同步）
+        :param is_retry: 使用api时，如遇可重试的错误码是否自动进行重试，默认开启
+        :param is_log_error: 使用api时，如返回的结果为不成功，可自动log输出报错信息，默认开启
+        :param shard_no: 当前分片数，如不熟悉相关配置请不要轻易改动此项，默认0
+        :param total_shard: 最大分片数，如不熟悉相关配置请不要轻易改动此项，默认1
         """
         self.logger = Logger(bot_id)
         self.bot_id = bot_id
@@ -57,7 +58,8 @@ class BOT:
                 '你还没有输入 bot_id 和 bot_token，无法连接使用机器人\n如尚未有相关票据，'
                 '请参阅 https://thoughts.teambition.com/share/627533408adeb10041b935b1#title=快速入门 了解相关详情')
         self.intents = 0
-        self.max_shard = max_shard
+        self.shard_no = shard_no
+        self.total_shard = total_shard
         self.__on_delete_function = None
         self.__on_msg_function = None
         self.__on_dm_function = None
@@ -74,15 +76,14 @@ class BOT:
         self.is_filter_self = True
         self.check_interval = 10
         self.running = False
-        self.bot_headers = {'Authorization': "Bot " + str(self.bot_id) + "." + str(self.bot_token)}
+        self.bot_headers = {'Authorization': f"Bot {self.bot_id}.{self.bot_token}"}
         self.__ssl = SSLContext()
         self.__session = Session()
         self.__session.headers = self.bot_headers
         self.__session.keep_alive = False
         self.__session.mount('http://', adapter)
         self.__session.mount('https://', adapter)
-        self.__bot_classes = []
-        self.__bot_threads = []
+        self.__bot_class = None
         self.__loop = get_event_loop()
         self.msg_treat = True
         self.dm_treat = False
@@ -90,11 +91,12 @@ class BOT:
         self.is_async = is_async
         if not is_async:
             self.api = API(self.bot_url, bot_id, bot_secret, self.__session, self.logger, self.check_warning,
-                           self.__get_bot_id)
+                           self.__get_bot_id, is_retry, is_log_error)
         else:
             from .async_api import AsyncAPI
             self.api: Union[API, AsyncAPI] = AsyncAPI(self.bot_url, bot_id, bot_secret, self.__ssl, self.bot_headers,
-                                                      self.logger, self.__loop, self.check_warning, self.__get_bot_id)
+                                                      self.logger, self.__loop, self.check_warning, self.__get_bot_id,
+                                                      is_retry, is_log_error)
 
     async def __time_event_check(self):
         while self.running:
@@ -278,7 +280,7 @@ class BOT:
         :return: 返回的.data中为机器人用户ID，如未注册则返回None
         """
         try:
-            return objectize({'data': self.__bot_classes[0].bot_qid, 'result': True})
+            return objectize({'data': self.__bot_class.bot_qid, 'result': True})
         except IndexError:
             return objectize({'data': None, 'result': False})
 
@@ -295,7 +297,7 @@ class BOT:
             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b52
         """
         try:
-            if not self.running:
+            if not self.running and not self.__bot_class:
                 self.running = True
                 gateway = self.__session.get(self.bot_url + '/gateway/bot').json()
                 if 'url' not in gateway.keys():
@@ -304,38 +306,17 @@ class BOT:
                         '请参阅 https://thoughts.teambition.com/share/627533408adeb10041b935b1#title=快速入门 了解相关详情')
                 url = gateway["url"]
                 self.logger.debug('[机器人ws地址] ' + url)
-                _shard = gateway["shards"]
-                self.logger.debug('[建议分片数] ' + str(_shard))
-                if _shard > self.max_shard:
-                    _shard = self.max_shard
-                    self.logger.info('[注意] 由于最大分片数少于建议分片数，分片数已自动调整为 ' + str(self.max_shard))
                 if self.__repeat_function is not None:
                     self.__loop.create_task(self.__time_event_check())
-                for shard_no in range(0, _shard):
-                    self.__bot_classes.append(
-                        BotWs(self.__session, self.__ssl, self.logger, _shard, shard_no, url, self.bot_id,
-                              self.bot_token, self.bot_url, self.__on_msg_function, self.__on_dm_function,
-                              self.__on_delete_function, self.is_filter_self, self.__on_guild_event_function,
-                              self.__on_channel_event_function, self.__on_guild_member_function,
-                              self.__on_reaction_function, self.__on_interaction_function, self.__on_audit_function,
-                              self.__on_forum_function, self.__on_audio_function, self.intents, self.msg_treat,
-                              self.dm_treat, self.__on_start_function, self.is_async))
-                if len(self.__bot_classes) == 1:
-                    self.__bot_classes[0].ws_starter()
-                else:
-                    if self.is_async:
-                        for bot_class in self.__bot_classes:
-                            if bot_class != self.__bot_classes[-1]:
-                                self.__loop.create_task(bot_class.ws_starter())
-                            else:
-                                bot_class.ws_starter()
-                    else:
-                        for bot_class in self.__bot_classes:
-                            thread = Thread(target=bot_class.ws_starter)
-                            thread.setDaemon(True)
-                            thread.start()
-                            self.__bot_threads.append(thread)
-                        self.__bot_threads[-1].join()
+                self.__bot_class = BotWs(self.__session, self.__ssl, self.logger, self.total_shard, self.shard_no, url,
+                                         self.bot_id, self.bot_token, self.bot_url, self.__on_msg_function,
+                                         self.__on_dm_function, self.__on_delete_function, self.is_filter_self,
+                                         self.__on_guild_event_function, self.__on_channel_event_function,
+                                         self.__on_guild_member_function, self.__on_reaction_function,
+                                         self.__on_interaction_function, self.__on_audit_function,
+                                         self.__on_forum_function, self.__on_audio_function, self.intents,
+                                         self.msg_treat, self.dm_treat, self.__on_start_function, self.is_async)
+                self.__bot_class.ws_starter()
             else:
                 self.logger.error('当前机器人已在运行中！')
         except KeyboardInterrupt:
@@ -351,12 +332,15 @@ class BOT:
         """
         if self.running:
             self.running = False
-            self.logger.info('所有WS链接已开始结束进程，请等待另一端完成握手并等待 TCP 连接终止')
-            for bot_class in self.__bot_classes:
-                bot_class.running = False
-            while True:
-                if self.__bot_classes[-1].ws.closed:
-                    self.logger.info('所有WS链接已结束')
-                    break
+            self.logger.info('WS链接已开始结束进程，请等待另一端完成握手并等待 TCP 连接终止')
+            self.__bot_class.running = False
+            timeout = self.__loop.time() + 60
+            while self.__loop.time() > timeout:
+                t_sleep(1)
+                if not self.__bot_class or self.__bot_class.ws.closed:
+                    self.logger.info('WS链接已结束')
+                    return
+            self.__bot_class = None
+            self.logger.info('判断超时，WS链接已强制结束')
         else:
             self.logger.error('当前机器人没有运行！')
